==> mongodb-src-r3.1.3.zip: mongodb-src-r3.1.3/src/mongo/db/repl/initial_sync.h <==
/**
 *    Copyright (C) 2008 10gen Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/db/repl/sync_tail.h"

namespace mongo {
namespace repl {

    class BackgroundSyncInterface;

    /**
     * Initial clone and sync
     */
    class InitialSync : public SyncTail {
    public:
        virtual ~InitialSync();
        InitialSync(BackgroundSyncInterface *q);

        /**
         * applies up to endOpTime, fetching missing documents as needed.
         */
        void oplogApplication(OperationContext* txn, const Timestamp& endOpTime);

        // Initial sync will ignore all journal requirement flags and doesn't wait until
        // operations are durable before updating the last OpTime.
        virtual bool supportsWaitingUntilDurable() { return false; }
    };

    // Used for ReplSetTest testing.
    extern unsigned replSetForceInitialSyncFailure;

} // namespace repl
} // namespace mongo

==> mongodb-src-r3.1.8.zip: mongodb-src-r3.1.8/src/mongo/db/repl/initial_sync.h <==
/**
 *    Copyright (C) 2008 10gen Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/db/repl/sync_tail.h"

namespace mongo {
namespace repl {

class BackgroundSyncInterface;

/**
 * Initial clone and sync
 */
class InitialSync : public SyncTail {
public:
    virtual ~InitialSync();
    InitialSync(BackgroundSyncInterface* q);

    /**
     * applies up to endOpTime, fetching missing documents as needed.
     */
    void oplogApplication(OperationContext* txn, const OpTime& endOpTime);

    // Initial sync will ignore all journal requirement flags and doesn't wait until
    // operations are durable before updating the last OpTime.
    virtual bool supportsWaitingUntilDurable() {
        return false;
    }
};

// Used for ReplSetTest testing.
extern unsigned replSetForceInitialSyncFailure;

}  // namespace repl
}  // namespace mongo
